# DiscordOAuth2
automatically follows through with the requests for Discord OAuth

[![Documentation Status](https://readthedocs.org/projects/async-disoauth2/badge/?version=latest)](https://async-disoauth2.readthedocs.io/en/latest/?badge=latest)

***

## Features
- Makes a Authorization Url automatically, using the client ID, redirect_uri, and the scopes you want
- Nothing else, working on getting the json data from the query string

***

## What I'm working on for version 2.0.0

- [x] Get Guilds
- [ ] Models
- [ ] Bot OAuth
